@@ -1,17 +1,16 @@
-use strict;
 use warnings;
 
 package Git::Hooks::CheckLog;
 # ABSTRACT: Git::Hooks plugin to enforce commit log policies
-$Git::Hooks::CheckLog::VERSION = '2.14.0';
-use 5.010;
+$Git::Hooks::CheckLog::VERSION = '3.0.0';
+use 5.016;
 use utf8;
 use Log::Any '$log';
 use Git::Hooks;
 use Git::Message;
 use List::MoreUtils qw/uniq/;
 
-(my $CFG = __PACKAGE__) =~ s/.*::/githooks./;
+my $CFG = __PACKAGE__ =~ s/.*::/githooks./r;
 
 #############
 # Grok hook configuration, check it and set defaults.
@@ -308,45 +307,14 @@ sub message_errors {
 }
 
 sub check_message_file {
-    my ($git, $commit_msg_file) = @_;
+    my ($git, $msg) = @_;
 
-    $log->debug(__PACKAGE__ . "::check_message_file($commit_msg_file)");
-
-    _setup_config($git);
-
-    my $current_branch = $git->get_current_branch();
-
-    return 1 unless $git->is_reference_enabled($current_branch);
-
-    if (my @ref = $git->get_config($CFG => 'ref')) {
-        return 1 unless $git->is_ref_enabled($current_branch, @ref);
-    }
-    if (my @noref = $git->get_config($CFG => 'noref')) {
-        return 0 if $git->is_ref_enabled($current_branch, @noref);
-    }
-
-    my $msg = eval {$git->read_commit_msg_file($commit_msg_file)};
-
-    unless (defined $msg) {
-        $git->fault(<<"EOS", {details => $@});
-I cannot read the commit message file '$commit_msg_file'.
-EOS
-        return 0;
-    }
-
-    return message_errors($git, undef, $msg) == 0;
+    return message_errors($git, undef, $msg);
 }
 
 sub check_ref {
     my ($git, $ref) = @_;
 
-    if (my @ref = $git->get_config($CFG => 'ref')) {
-        return 1 unless $git->is_ref_enabled($ref, @ref);
-    }
-    if (my @noref = $git->get_config($CFG => 'noref')) {
-        return 0 if $git->is_ref_enabled($ref, @noref);
-    }
-
     my $errors = 0;
 
     foreach my $commit ($git->get_affected_ref_commits($ref)) {
@@ -356,68 +324,18 @@ sub check_ref {
     return $errors == 0;
 }
 
-# This routine can act both as an update or a pre-receive hook.
-sub check_affected_refs {
-    my ($git) = @_;
-
-    $log->debug(__PACKAGE__ . "::check_affected_refs");
-
-    _setup_config($git);
-
-    return 1 if $git->im_admin();
-
-    my $errors = 0;
-
-    foreach my $ref ($git->get_affected_refs()) {
-        next unless $git->is_reference_enabled($ref);
-        check_ref($git, $ref)
-            or ++$errors;
-    }
-
-    return $errors == 0;
-}
-
 sub check_patchset {
-    my ($git, $opts) = @_;
+    my ($git, $branch, $commit) = @_;
 
-    $log->debug(__PACKAGE__ . "::check_patchset");
-
-    _setup_config($git);
-
-    return 1 if $git->im_admin();
-
-    my $sha1   = $opts->{'--commit'};
-    my $commit = $git->get_commit($sha1);
-
-    # The --branch argument contains the branch short-name if it's in the
-    # refs/heads/ namespace. But we need to always use the branch long-name,
-    # so we change it here.
-    my $branch = $opts->{'--branch'};
-    $branch = "refs/heads/$branch"
-        unless $branch =~ m:^refs/:;
-
-    return 1 unless $git->is_reference_enabled($branch);
-
-    if (my @ref = $git->get_config($CFG => 'ref')) {
-        return 1 unless $git->is_ref_enabled($branch, @ref);
-    }
-    if (my @noref = $git->get_config($CFG => 'noref')) {
-        return 0 if $git->is_ref_enabled($branch, @noref);
-    }
-
-    return message_errors($git, $commit, $commit->message) == 0;
+    return message_errors($git, $commit, $commit->message);
 }
 
 # Install hooks
-APPLYPATCH_MSG   \&check_message_file;
-COMMIT_MSG       \&check_message_file;
-UPDATE           \&check_affected_refs;
-PRE_RECEIVE      \&check_affected_refs;
-REF_UPDATE       \&check_affected_refs;
-COMMIT_RECEIVED  \&check_affected_refs;
-SUBMIT           \&check_affected_refs;
-PATCHSET_CREATED \&check_patchset;
-DRAFT_PUBLISHED  \&check_patchset;
+my $options = {config => \&_setup_config};
+
+GITHOOKS_CHECK_AFFECTED_REFS \&check_ref,          $options;
+GITHOOKS_CHECK_PATCHSET      \&check_patchset,     $options;
+GITHOOKS_CHECK_MESSAGE_FILE  \&check_message_file, $options;
 
 1;
 
@@ -433,7 +351,7 @@ Git::Hooks::CheckLog - Git::Hooks plugin to enforce commit log policies
 
 =head1 VERSION
 
-version 2.14.0
+version 3.0.0
 
 =head1 SYNOPSIS
 
@@ -533,7 +451,7 @@ option:
     [githooks]
       plugin = CheckLog
 
-=for Pod::Coverage spelling_errors pattern_errors revert_errors title_errors body_errors footer_errors message_errors check_ref check_affected_refs check_message_file check_patchset
+=for Pod::Coverage spelling_errors pattern_errors revert_errors title_errors body_errors footer_errors message_errors check_ref check_message_file check_patchset
 
 =head1 NAME
 
@@ -672,33 +590,6 @@ doesn't invoke the C<commit-msg> hook, so that this check can't be performed at
 commit time. The checking will be performed at push time by a C<pre-receive> or
 C<update> hook though.
 
-=head2 [DEPRECATED] ref REFSPEC
-
-This option is DEPRECATED. Please, use the C<githooks.ref> option instead.
-
-By default, the message of every commit is checked. If you want to
-have them checked only for some refs (usually some branch under
-refs/heads/), you may specify them with one or more instances of this
-option.
-
-The refs can be specified as a complete ref name
-(e.g. "refs/heads/master") or by a regular expression starting with a
-caret (C<^>), which is kept as part of the regexp
-(e.g. "^refs/heads/(master|fix)").
-
-=head2 [DEPRECATED] noref REFSPEC
-
-This option is DEPRECATED. Please, use the C<githooks.noref> option instead.
-
-By default, the message of every commit is checked. If you want to exclude
-some refs (usually some branch under refs/heads/), you may specify them with
-one or more instances of this option.
-
-The refs can be specified as in the same way as to the C<ref> option above.
-
-Note that the C<ref> option has precedence over the C<noref> option, i.e.,
-if a reference matches both options it will be checked.
-
 =head1 REFERENCES
 
 =over
