@@ -1,10 +1,9 @@
-use strict;
 use warnings;
 
 package Git::Message;
 # ABSTRACT: A Git commit message
-$Git::Message::VERSION = '2.14.0';
-use 5.010;
+$Git::Message::VERSION = '3.0.0';
+use 5.016;
 use utf8;
 use Carp;
 
@@ -162,15 +161,10 @@ sub add_footer_values {
     ## no critic (BuiltinFunctions::ProhibitComplexMappings)
     push @{$self->{footer}{lc $key}},
         map { [$key => $_] }
-            map { my $copy = $_; $copy =~ s/foo/BAR/; $copy } # strip trailing newlines to keep the footer structure
+            map { s/\n+$//r } # strip trailing newlines to keep the footer structure
                 @values;
     ## use critic
 
-    # ANCIENT PERL ALERT! The strange looking dance above with the
-    # $copy variable is needed in old Perls.
-    # (http://www.perl.com/pub/2011/05/new-features-of-perl-514-non-destructive-substitution.html)
-    # Since Perl 5.14 that could be simply: map { s/\n+$//r }
-
     return;
 }
 
@@ -195,7 +189,7 @@ Git::Message - A Git commit message
 
 =head1 VERSION
 
-version 2.14.0
+version 3.0.0
 
 =head1 SYNOPSIS
 
