@@ -1,12 +1,11 @@
-use strict;
 use warnings;
 
 package Git::Repository::Plugin::GitHooks;
 # ABSTRACT: A Git::Repository plugin with some goodies for hook developers
-$Git::Repository::Plugin::GitHooks::VERSION = '2.14.0';
+$Git::Repository::Plugin::GitHooks::VERSION = '3.0.0';
 use parent qw/Git::Repository::Plugin/;
 
-use 5.010;
+use 5.016;
 use utf8;
 use Carp;
 use Path::Tiny;
@@ -25,7 +24,7 @@ sub _keywords {                 ## no critic (ProhibitUnusedPrivateSubroutines)
 
           get_config get_config_boolean get_config_integer
 
-          error get_errors fault get_faults
+          fault get_faults
 
           undef_commit empty_tree get_commit get_commits
 
@@ -43,7 +42,7 @@ sub _keywords {                 ## no critic (ProhibitUnusedPrivateSubroutines)
 
           blob file_size file_mode
 
-          is_reference_enabled is_ref_enabled match_user im_admin grok_acls
+          is_reference_enabled match_user im_admin grok_acls
       /;
 }
 
@@ -268,16 +267,16 @@ sub _gerrit_patchset_post_hook {
     my %review_input = (tag => 'autogenerated:git-hooks');
     my $auto_submit = 0;
 
-    if (my $errors = $git->get_errors()) {
+    if (my $faults = $git->get_faults()) {
         $review_input{labels}  = $cfg{'votes-to-reject'} || 'Code-Review-1';
 
-        # We have to truncate $errors down to a little less than 64kB because up
+        # We have to truncate $faults down to a little less than 64kB because up
         # to at least Gerrit 2.14.4 messages are saved in a MySQL column of type
         # 'text', which has this limit.
-        if (length $errors > 65000) {
-            $errors = substr($errors, 0, 65000) . "...\n<truncated>\n";
+        if (length $faults > 65000) {
+            $faults = substr($faults, 0, 65000) . "...\n<truncated>\n";
         }
-        $review_input{message} = $errors;
+        $review_input{message} = $faults;
     } else {
         $review_input{labels}  = $cfg{'votes-to-approve'} || 'Code-Review+1';
         $review_input{message} = "[Git::Hooks] $cfg{'comment-ok'}"
@@ -726,29 +725,6 @@ sub get_config_integer {
     }
 }
 
-# DEPRECATED: use fault instead!
-sub error {
-    my ($git, $prefix, $message, $details) = @_;
-    $message =~ s/\n*$//s;    # strip trailing newlines
-    my $fmtmsg = "\n[$prefix] $message";
-    if (defined $details) {
-        $details =~ s/\n*$//s; # strip trailing newlines
-        $details =~ s/^/  /gm; # prefix each line with two spaces
-        $fmtmsg .= ":\n\n$details\n";
-    }
-    $fmtmsg .= "\n";            # end in a newline
-    push @{$git->{_plugin_githooks}{faults}}, $fmtmsg;
-
-    # Return true to allow for the idiom: <expression> or $git->error(...) and <next|last|return>;
-    return 1;
-}
-
-# DEPRECATED: use get_faults instead!
-sub get_errors {
-    my @args = @_;
-    return get_faults(@args);
-}
-
 sub _githooks_colors {
     my ($git) = @_;
 
@@ -1325,7 +1301,7 @@ sub blob {
         my $path = path($file);
 
         # Calculate temporary file path
-        (my $revdir  = $rev) =~ s/^://; # remove ':' from ':0' because Windows don't like ':' in filenames
+        my $revdir = $rev =~ s/^://r; # remove ':' from ':0' because Windows don't like ':' in filenames
         my $filepath = $cache->{tmpdir}->child($revdir, $path);
 
         # Create directory path for the temporary file.
@@ -1405,23 +1381,6 @@ sub file_mode {
     croak "Can't happen!";
 }
 
-## DEPRECATED
-sub is_ref_enabled {
-    my ($git, $ref, @specs) = @_;
-
-    return 1 if ! defined $ref || @specs == 0;
-
-    foreach (@specs) {
-        if (/^\^/) {
-            return 1 if $ref =~ qr/$_/;
-        } else {
-            return 1 if $ref eq $_;
-        }
-    }
-
-    return 0;
-}
-
 sub is_reference_enabled {
     my ($git, $reference) = @_;
 
@@ -1599,7 +1558,7 @@ Git::Repository::Plugin::GitHooks - A Git::Repository plugin with some goodies f
 
 =head1 VERSION
 
-version 2.14.0
+version 3.0.0
 
 =head1 SYNOPSIS
 
@@ -1902,14 +1861,6 @@ This method returns a string specially formatted with all error messages
 recorded with the C<fault> method, a header, and a footer, if requested by
 configuration.
 
-=head2 error PREFIX MESSAGE [DETAILS]
-
-This method is DEPRECATED. Please, use C<fault> instead.
-
-=head2 get_errors
-
-This method is DEPRECATED. Please, use C<get_faults> instead.
-
 =head2 undef_commit
 
 The undefined commit is a special SHA-1 used by Git in the update and
@@ -2210,26 +2161,6 @@ The method decides if a reference is enabled using the following algorithm:
 
 =back
 
-=head2 is_ref_enabled REF, SPECs...
-
-This method is DEPRECATED. Please, use the C<is_reference_enabled> method
-instead.
-
-Returns a Boolean indicating if REF matches one of the ref-specs in
-SPECS. REF is the complete name of a Git ref and SPECS is a list of strings,
-each one specifying a rule for matching ref names.
-
-As a special case, it returns true if REF is undef or if there is no SPEC
-whatsoever, meaning that by default all refs/commits are enabled.
-
-You may want to use it, for example, in an C<update>, C<pre-receive>, or
-C<post-receive> hook which may be enabled depending on the particular refs
-being affected.
-
-Each SPEC rule may indicate the matching refs as the complete ref name
-(e.g. C<refs/heads/master>) or by a regular expression starting with a caret
-(C<^>), which is kept as part of the regexp.
-
 =head2 match_user SPEC
 
 Checks if the authenticated user (as returned by the C<authenticated_user>
